@@ -386,7 +386,7 @@ Vytvářím tmp soubor.</translation>
     </message>
     <message>
         <source>&amp;Preview</source>
-        <translation>&amp;Náhled</translation>
+        <translation type="obsolete">&amp;Náhled</translation>
     </message>
     <message>
         <source>Ctrl+P</source>
@@ -400,6 +400,10 @@ Vytvářím tmp soubor.</translation>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Preview</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChangeCategoryFrm</name>
@@ -518,6 +522,10 @@ Vytvářím tmp soubor.</translation>
         <source>&amp;Cancel</source>
         <translation>&amp;Zrušit</translation>
     </message>
+    <message>
+        <source>Learn new cards in random order</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -698,6 +706,10 @@ takže by jste potom měl(a) provést </translation>
         <source>&amp;Find</source>
         <translation>&amp;Hledat</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="obsolete"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemsFrm</name>
@@ -733,6 +745,10 @@ takže by jste potom měl(a) provést </translation>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ExportDlg</name>
@@ -910,7 +926,7 @@ takže by jste potom měl(a) provést </translation>
     </message>
     <message>
         <source>Show &amp;answer</source>
-        <translation>Ukázat &amp;odpověď</translation>
+        <translation type="obsolete">Ukázat &amp;odpověď</translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
@@ -936,6 +952,10 @@ takže by jste potom měl(a) provést </translation>
         <source>All: </source>
         <translation>Všech: </translation>
     </message>
+    <message>
+        <source>Show answer</source>
+        <translation type="unfinished">Ukázat odpověď</translation>
+    </message>
 </context>
 <context>
     <name>MainFrm</name>
@@ -1426,6 +1446,34 @@ Další dokumentace viz. http://www.mnemosyne-proj.sourceforge.net.
         <source>Grade</source>
         <translation>Hodnocení</translation>
     </message>
+    <message>
+        <source>No current card.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Grade:</source>
+        <translation type="unfinished">Hodnocení:</translation>
+    </message>
+    <message>
+        <source>Easiness:</source>
+        <translation type="unfinished">Jednoduchost:</translation>
+    </message>
+    <message>
+        <source>Repetitions:</source>
+        <translation type="unfinished">Opakování:</translation>
+    </message>
+    <message>
+        <source>Lapses:</source>
+        <translation type="unfinished">Zapomenutí:</translation>
+    </message>
+    <message>
+        <source>Days since last repetition:</source>
+        <translation type="unfinished">Dnů od posledního opakování:</translation>
+    </message>
+    <message>
+        <source>Days until next repetition:</source>
+        <translation type="unfinished">Dnů do dalšího opakování:</translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
@@ -1457,6 +1505,10 @@ Další dokumentace viz. http://www.mnemosyne-proj.sourceforge.net.
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
+    <message>
+        <source>Current card</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TipDlg</name>
