@@ -389,7 +389,7 @@ Erstelle temporäre Datei.</translation>
     </message>
     <message>
         <source>&amp;Preview</source>
-        <translation>&amp;Vorschau</translation>
+        <translation type="obsolete">&amp;Vorschau</translation>
     </message>
     <message>
         <source>Ctrl+P</source>
@@ -403,6 +403,10 @@ Erstelle temporäre Datei.</translation>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Preview</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChangeCategoryFrm</name>
@@ -521,6 +525,10 @@ Erstelle temporäre Datei.</translation>
         <source>&amp;Cancel</source>
         <translation>&amp;Abbrechen</translation>
     </message>
+    <message>
+        <source>Learn new cards in random order</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -701,6 +709,10 @@ Vielleicht möchtest Du </translation>
         <source>Add &amp;vice versa</source>
         <translation>Ver&amp;tauscht hinzufügen</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="obsolete"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemsFrm</name>
@@ -736,6 +748,10 @@ Vielleicht möchtest Du </translation>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ExportDlg</name>
@@ -905,7 +921,7 @@ Vielleicht möchtest Du </translation>
     </message>
     <message>
         <source>Show &amp;answer</source>
-        <translation>&amp;Antwort anzeigen</translation>
+        <translation type="obsolete">&amp;Antwort anzeigen</translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
@@ -939,6 +955,10 @@ Vielleicht möchtest Du </translation>
         <source> days.</source>
         <translation> Tage.</translation>
     </message>
+    <message>
+        <source>Show answer</source>
+        <translation type="unfinished">Antwort anzeigen</translation>
+    </message>
 </context>
 <context>
     <name>MainFrm</name>
@@ -1453,6 +1473,34 @@ Viel Spass und Erfolg!</translation>
         <source>Grade</source>
         <translation>Bewertung</translation>
     </message>
+    <message>
+        <source>No current card.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Grade:</source>
+        <translation type="unfinished">Bewertung:</translation>
+    </message>
+    <message>
+        <source>Easiness:</source>
+        <translation type="unfinished">Leichtigkeit:</translation>
+    </message>
+    <message>
+        <source>Repetitions:</source>
+        <translation type="unfinished">Wiederholungen:</translation>
+    </message>
+    <message>
+        <source>Lapses:</source>
+        <translation type="unfinished">Fehler:</translation>
+    </message>
+    <message>
+        <source>Days since last repetition:</source>
+        <translation type="unfinished">Tage seit der letzten Wiederholung:</translation>
+    </message>
+    <message>
+        <source>Days until next repetition:</source>
+        <translation type="unfinished">Tage bis zur nächsten Wiederholung:</translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
@@ -1484,6 +1532,10 @@ Viel Spass und Erfolg!</translation>
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
+    <message>
+        <source>Current card</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TipDlg</name>
