@@ -376,7 +376,7 @@ Creating tmp file.</source>
     </message>
     <message>
         <source>&amp;Preview</source>
-        <translation>پیش نمایش</translation>
+        <translation type="obsolete">پیش نمایش</translation>
     </message>
     <message>
         <source>Ctrl+P</source>
@@ -390,6 +390,10 @@ Creating tmp file.</source>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Preview</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChangeCategoryFrm</name>
@@ -508,6 +512,10 @@ Creating tmp file.</source>
         <source>&amp;Cancel</source>
         <translation>انصراف</translation>
     </message>
+    <message>
+        <source>Learn new cards in random order</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -685,6 +693,10 @@ so you might want to run </source>
         <source>&amp;Find</source>
         <translation>بگرد</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="obsolete"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemsFrm</name>
@@ -720,6 +732,10 @@ so you might want to run </source>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ExportDlg</name>
@@ -897,7 +913,7 @@ so you might want to run </source>
     </message>
     <message>
         <source>Show &amp;answer</source>
-        <translation>پاسخ را نشان بده</translation>
+        <translation type="obsolete">پاسخ را نشان بده</translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
@@ -923,6 +939,10 @@ so you might want to run </source>
         <source>All: </source>
         <translation>همه: </translation>
     </message>
+    <message>
+        <source>Show answer</source>
+        <translation type="unfinished">پاسخ را نشان بده</translation>
+    </message>
 </context>
 <context>
     <name>MainFrm</name>
@@ -1387,6 +1407,34 @@ Happy learning!</source>
         <source>Grade</source>
         <translation>رتبه</translation>
     </message>
+    <message>
+        <source>No current card.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Grade:</source>
+        <translation type="unfinished">مرتبه:</translation>
+    </message>
+    <message>
+        <source>Easiness:</source>
+        <translation type="unfinished">آسانی:</translation>
+    </message>
+    <message>
+        <source>Repetitions:</source>
+        <translation type="unfinished">تکرارها:</translation>
+    </message>
+    <message>
+        <source>Lapses:</source>
+        <translation type="unfinished">خطاها:</translation>
+    </message>
+    <message>
+        <source>Days since last repetition:</source>
+        <translation type="unfinished">روزهای بعد از آخرین مرور:</translation>
+    </message>
+    <message>
+        <source>Days until next repetition:</source>
+        <translation type="unfinished">روزهای قبل از مرور بعدی:</translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
@@ -1418,6 +1466,10 @@ Happy learning!</source>
         <source>&amp;OK</source>
         <translation>بسیارخوب</translation>
     </message>
+    <message>
+        <source>Current card</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TipDlg</name>
