@@ -390,7 +390,7 @@ Création d&apos;un fichier tmp.</translation>
     </message>
     <message>
         <source>&amp;Preview</source>
-        <translation>A&amp;perçu</translation>
+        <translation type="obsolete">A&amp;perçu</translation>
     </message>
     <message>
         <source>Ctrl+P</source>
@@ -404,6 +404,10 @@ Création d&apos;un fichier tmp.</translation>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Preview</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChangeCategoryFrm</name>
@@ -522,6 +526,10 @@ Création d&apos;un fichier tmp.</translation>
         <source>&amp;Cancel</source>
         <translation>&amp;Annuler</translation>
     </message>
+    <message>
+        <source>Learn new cards in random order</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -702,6 +710,10 @@ so you might want to run </source>
         <source>&amp;Find</source>
         <translation>Re&amp;chercher</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="obsolete"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemsFrm</name>
@@ -737,6 +749,10 @@ so you might want to run </source>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ExportDlg</name>
@@ -914,7 +930,7 @@ so you might want to run </source>
     </message>
     <message>
         <source>Show &amp;answer</source>
-        <translation>Afficher la &amp;réponse</translation>
+        <translation type="obsolete">Afficher la &amp;réponse</translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
@@ -940,6 +956,10 @@ so you might want to run </source>
         <source>All: </source>
         <translation>Total : </translation>
     </message>
+    <message>
+        <source>Show answer</source>
+        <translation type="unfinished">Afficher la réponse</translation>
+    </message>
 </context>
 <context>
     <name>MainFrm</name>
@@ -1426,6 +1446,34 @@ Joyeux apprentissage!</translation>
         <source>Grade</source>
         <translation>Note</translation>
     </message>
+    <message>
+        <source>No current card.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Grade:</source>
+        <translation type="unfinished">Note :</translation>
+    </message>
+    <message>
+        <source>Easiness:</source>
+        <translation type="unfinished">Facilité :</translation>
+    </message>
+    <message>
+        <source>Repetitions:</source>
+        <translation type="unfinished">Répétitions :</translation>
+    </message>
+    <message>
+        <source>Lapses:</source>
+        <translation type="unfinished">Oubils :</translation>
+    </message>
+    <message>
+        <source>Days since last repetition:</source>
+        <translation type="unfinished">Jours depuis la dernière répétition :</translation>
+    </message>
+    <message>
+        <source>Days until next repetition:</source>
+        <translation type="unfinished">Jours jusqu&apos;à la prochaine répétition :</translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
@@ -1457,6 +1505,10 @@ Joyeux apprentissage!</translation>
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
+    <message>
+        <source>Current card</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TipDlg</name>
