@@ -390,7 +390,7 @@ Ik creëer tmp bestand.</translation>
     </message>
     <message>
         <source>&amp;Preview</source>
-        <translation>&amp;Voorvertoning</translation>
+        <translation type="obsolete">&amp;Voorvertoning</translation>
     </message>
     <message>
         <source>Ctrl+P</source>
@@ -404,6 +404,10 @@ Ik creëer tmp bestand.</translation>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Preview</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChangeCategoryFrm</name>
@@ -522,6 +526,10 @@ Ik creëer tmp bestand.</translation>
         <source>&amp;Cancel</source>
         <translation>&amp;Annuleer</translation>
     </message>
+    <message>
+        <source>Learn new cards in random order</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -702,6 +710,10 @@ dus wellicht wilt u </translation>
         <source>&amp;Find</source>
         <translation>&amp;Zoek</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="obsolete"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemsFrm</name>
@@ -737,6 +749,10 @@ dus wellicht wilt u </translation>
         <source>Alt+X</source>
         <translation>Alt+A</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ExportDlg</name>
@@ -906,7 +922,7 @@ dus wellicht wilt u </translation>
     </message>
     <message>
         <source>Show &amp;answer</source>
-        <translation>Toon &amp;antwoord</translation>
+        <translation type="obsolete">Toon &amp;antwoord</translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
@@ -940,6 +956,10 @@ dus wellicht wilt u </translation>
         <source> days.</source>
         <translation type="unfinished"> dagen.</translation>
     </message>
+    <message>
+        <source>Show answer</source>
+        <translation type="unfinished">Toon anwoord</translation>
+    </message>
 </context>
 <context>
     <name>MainFrm</name>
@@ -1454,6 +1474,34 @@ Veel plezier met leren!</translation>
         <source>Grade</source>
         <translation>Beoordeling</translation>
     </message>
+    <message>
+        <source>No current card.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Grade:</source>
+        <translation type="unfinished">Beoordeling:</translation>
+    </message>
+    <message>
+        <source>Easiness:</source>
+        <translation type="unfinished">Eenvoud:</translation>
+    </message>
+    <message>
+        <source>Repetitions:</source>
+        <translation type="unfinished">Herhalingen:</translation>
+    </message>
+    <message>
+        <source>Lapses:</source>
+        <translation type="unfinished">Uitvoeringen:</translation>
+    </message>
+    <message>
+        <source>Days since last repetition:</source>
+        <translation type="unfinished">Aantal dagen vanaf laatste bevraging:</translation>
+    </message>
+    <message>
+        <source>Days until next repetition:</source>
+        <translation type="unfinished">Dagen tot volgende bevraging:</translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
@@ -1485,6 +1533,10 @@ Veel plezier met leren!</translation>
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
+    <message>
+        <source>Current card</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TipDlg</name>
