@@ -382,7 +382,7 @@ Tworzenie pliku tymczasowego &quot;tmp&quot;.</translation>
     </message>
     <message>
         <source>&amp;Preview</source>
-        <translation>&amp;Podgląd</translation>
+        <translation type="obsolete">&amp;Podgląd</translation>
     </message>
     <message>
         <source>Ctrl+P</source>
@@ -396,6 +396,10 @@ Tworzenie pliku tymczasowego &quot;tmp&quot;.</translation>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Preview</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChangeCategoryFrm</name>
@@ -514,6 +518,10 @@ Tworzenie pliku tymczasowego &quot;tmp&quot;.</translation>
         <source>&amp;Cancel</source>
         <translation>&amp;Anuluj</translation>
     </message>
+    <message>
+        <source>Learn new cards in random order</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -694,6 +702,10 @@ Konieczne może być</translation>
         <source>&amp;Find</source>
         <translation>&amp;Szukaj</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="obsolete"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemsFrm</name>
@@ -729,6 +741,10 @@ Konieczne może być</translation>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ExportDlg</name>
@@ -906,7 +922,7 @@ Konieczne może być</translation>
     </message>
     <message>
         <source>Show &amp;answer</source>
-        <translation>Pokaż &amp;odpowiedź</translation>
+        <translation type="obsolete">Pokaż &amp;odpowiedź</translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
@@ -932,6 +948,10 @@ Konieczne może być</translation>
         <source>All: </source>
         <translation>Wszystkich: </translation>
     </message>
+    <message>
+        <source>Show answer</source>
+        <translation type="unfinished">Pokaż odpowiedź</translation>
+    </message>
 </context>
 <context>
     <name>MainFrm</name>
@@ -1422,6 +1442,34 @@ Przyjemnej nauki!</translation>
         <source>Grade</source>
         <translation>Ocena</translation>
     </message>
+    <message>
+        <source>No current card.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Grade:</source>
+        <translation type="unfinished">Ocena:</translation>
+    </message>
+    <message>
+        <source>Easiness:</source>
+        <translation type="unfinished">Łatwość:</translation>
+    </message>
+    <message>
+        <source>Repetitions:</source>
+        <translation type="unfinished">Powtórki:</translation>
+    </message>
+    <message>
+        <source>Lapses:</source>
+        <translation type="unfinished">Pomyłki:</translation>
+    </message>
+    <message>
+        <source>Days since last repetition:</source>
+        <translation type="unfinished">Liczba dni, które upłynęły od ostatniej powtórki:</translation>
+    </message>
+    <message>
+        <source>Days until next repetition:</source>
+        <translation type="unfinished">Liczba dni pozostałych do rozpoczęcia powtórki:</translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
@@ -1453,6 +1501,10 @@ Przyjemnej nauki!</translation>
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
+    <message>
+        <source>Current card</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TipDlg</name>
