@@ -376,7 +376,7 @@ Criando arquivo temporário.</translation>
     </message>
     <message>
         <source>&amp;Preview</source>
-        <translation type="unfinished">&amp;Pré visualizar</translation>
+        <translation type="obsolete">&amp;Pré visualizar</translation>
     </message>
     <message>
         <source>Ctrl+P</source>
@@ -390,6 +390,10 @@ Criando arquivo temporário.</translation>
         <source>Alt+X</source>
         <translation type="unfinished">Alt+X</translation>
     </message>
+    <message>
+        <source>Preview</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChangeCategoryFrm</name>
@@ -508,6 +512,10 @@ Criando arquivo temporário.</translation>
         <source>&amp;Cancel</source>
         <translation type="unfinished">&amp;Cancelar</translation>
     </message>
+    <message>
+        <source>Learn new cards in random order</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -686,6 +694,10 @@ então você pode querer executar a </translation>
         <source>&amp;Find</source>
         <translation type="unfinished">&amp;Procurar</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="obsolete"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemsFrm</name>
@@ -721,6 +733,10 @@ então você pode querer executar a </translation>
         <source>Alt+X</source>
         <translation type="unfinished">Alt+X</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ExportDlg</name>
@@ -898,7 +914,7 @@ então você pode querer executar a </translation>
     </message>
     <message>
         <source>Show &amp;answer</source>
-        <translation type="unfinished">Mostrar &amp;resposta</translation>
+        <translation type="obsolete">Mostrar &amp;resposta</translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
@@ -924,6 +940,10 @@ então você pode querer executar a </translation>
         <source>All: </source>
         <translation type="unfinished">Todos: </translation>
     </message>
+    <message>
+        <source>Show answer</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainFrm</name>
@@ -1410,6 +1430,34 @@ Boa aprendizagem!</translation>
         <source>Grade</source>
         <translation type="unfinished">Nível</translation>
     </message>
+    <message>
+        <source>No current card.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Grade:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Easiness:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Repetitions:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lapses:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Days since last repetition:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Days until next repetition:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
@@ -1441,6 +1489,10 @@ Boa aprendizagem!</translation>
         <source>&amp;OK</source>
         <translation type="unfinished">&amp;OK</translation>
     </message>
+    <message>
+        <source>Current card</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TipDlg</name>
